//********************* sx16f.h ***************************
//* This file contains sx16.dll functions declarations
//* for use with Sensoray model 516 MPEG codec.
//* Copyright (C) Sensoray 2001
//*********************************************************

#ifndef XFUNCX16
//Pointers to DLL functions
#define XFUNCX16(RTNTYPE,FUNCNAME)  extern RTNTYPE (__stdcall *FUNCNAME)
#endif


#ifdef __cplusplus
extern "C" {
#endif

//DLL load/unload functions
extern int X16_DLLOpen(void);
extern void X16_DLLClose(void);


//Pointers to sx16.dll exported functions
/*
// Resets the board
XFUNCX16(int, X16_reset)(int board);

// Init module. It checks base addresses, number of 516s, etc.
// Returns:
// -1  - driver open error
// >=0 - number of cards
XFUNCX16(int, X16_init)(PCI *pci);

// This is called when the module is unloaded
XFUNCX16(void, X16_close)(void);
*/

// Init driver
// Returns:
// number of cards or error code (negative)
XFUNCX16(int, X16_open)(void);

// Init and register board
// Returns:
// 0 if OK or error code
XFUNCX16(int, X16_register)(int board);

// Close and unregister board
XFUNCX16(void, X16_unregister)(int board);

// close the driver
XFUNCX16(void, X16_close)(void);

// Select video input, i.e. 0-4
XFUNCX16(void, X16_set_input)(int board,int input);

// Sets video input type, i.e. SVIDEO (1) or CVIDEO (0)
XFUNCX16(void, X16_set_input_type)(int board,int type);

// Set input video system, i.e. NTSC (2) or PAL (1)
XFUNCX16(void, X16_set_input_system)(int board,int system);

// Set output video system, i.e. NTSC (2) or PAL (1)
XFUNCX16(void, X16_set_output_system)(int board,int system);

// Set desired bit rate, typically 700,000 to 10,000,000
XFUNCX16(void, X16_set_bitrate)(int board,int rate);

// Set picture size and compression system
// 0 - MPEG-2, NTSC-704x480 PAL-704x576
// 1 - MPEG-2, NTSC-480x480 PAL-480x576
// 2 - MPEG-2, NTSC-352x480 PAL-352x576
// 3 - MPEG-1, NTSC-352x240 PAL-352x288
// 4 - MPEG-1, NTSC-176x112 PAL-176x144
// 5 - MPEG-2, NTSC-720x480 PAL-720x576
// 6 - MPEG-2, NTSC-640x480 PAL-640x576

XFUNCX16(void, X16_set_picsize)(int board,int size);

// Sets number of frames in Group of Pictures (1...15, default-15)
XFUNCX16(void, X16_set_m)(int board,int m);

// Sets distance between I/P frames (1...3, default-3)
XFUNCX16(void, X16_set_n)(int board,int n);

// Enables (1)/disables (0) variable bit rate compression
XFUNCX16(void, X16_set_vbr)(int board,int vbr);

// Reads state of GPIO inputs
XFUNCX16(int, X16_read_gpio)(int board);

// Sets state of GPIO outputs
XFUNCX16(void, X16_write_gpio)(int board,int state);

// Set brightness on video in
XFUNCX16(void, X16_set_brightness)(int board,int brightness);

// Set contrast on video in
XFUNCX16(void, X16_set_contrast)(int board,int contrast);

// Set saturation on video in
XFUNCX16(void, X16_set_saturation)(int board,int saturation);

// Set colors bars in video out
XFUNCX16(void, X16_set_colorbars)(int board,int bars);

// Set filter for low quality input
XFUNCX16(void, X16_set_filter)(int board,int filter);

//Prepare a buffer to capture uncompressed frames.
//User must specify desirable width and height.
//Function calculates compatable width and height (maybe different)
//and allocates capbuf with capsize (in bytes).
XFUNCX16(int,X16_prepare_capture)(int board,BUFFER *buf);

//Status set to 1 by X16_capture_start and cleared by hardware.
XFUNCX16(int,X16_get_capture_status)(int board);

//Start capture
XFUNCX16(int,X16_capture_start)(int board);

//Close and clear caption buffer
XFUNCX16(int,X16_close_capture)(int board);


XFUNCX16(int,X16_overlay_get)(int board,int *width,int *height);

XFUNCX16(int,X16_overlay_setmode)(int board,int mode);

XFUNCX16(int,X16_overlay_setpos)(int board,int xstart,int ystart,int xend,int yend);

XFUNCX16(int,X16_overlay_setcolors)(int board,int yfirst,int ynext,int c1,int c2);

XFUNCX16(int,X16_overlay_write)(int board,int row,int column,int data);


// Set audio volume (dB). 0 - maximum, 63 - minimum
XFUNCX16(void, X16_set_volume)(int board,unsigned int db);

// Set audio mute
XFUNCX16(void, X16_set_mute)(int board,int mute);

// Read method - Attempts to read "nbytes" bytes of MPEG data from the
//SM2210 output fifo. The actual ammount read is returned. If no data
//is available -1 is returned unless blocking has been enabled. In
//which case this function will wait until at least one byte of data is
//made available. If this is the first read the encoder is initialized
//and started.
XFUNCX16(int, X16_read)(int board,char *buffer,int nbytes);

// Write method - Attempts to write "nbytes" bytes of MPEG data to the
//SM2210 input fifo. The actual ammount written is returned. If this
//is the first write the decoder is initialized and started.
XFUNCX16(int, X16_write)(int board,char *buffer,int nbytes);

// Stop read/write
XFUNCX16(int, X16_stop)(int board);

// Pause read/write
XFUNCX16(int, X16_pause)(int board);

// Resume read/write after pause
XFUNCX16(int, X16_resume)(int board);


#ifdef __cplusplus
}
#endif

